==> keyclic_sdk_api-2.2.12.tar.gz: lib/model/document_links_file.dart <==
part of keyclic_sdk_api.api;

class DocumentLinksFile {
  DocumentLinksFile({
    this.href,
    this.iriTemplate,
  });

  factory DocumentLinksFile.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return DocumentLinksFile(
      href: json['href'],
      iriTemplate: DocumentLinksFileIriTemplate.fromJson(json['iriTemplate']),
    );
  }

  /* The URI of the file associated to the given document. */
  String href;

  DocumentLinksFileIriTemplate iriTemplate;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is DocumentLinksFile &&
        runtimeType == other.runtimeType &&
        href == other.href &&
        iriTemplate == other.iriTemplate;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= href?.hashCode ?? 0;
    hashCode ^= iriTemplate?.hashCode ?? 0;

    return hashCode;
  }

  static List<DocumentLinksFile> listFromJson(List<dynamic> json) {
    return json == null
        ? <DocumentLinksFile>[]
        : json
            .map((dynamic value) => DocumentLinksFile.fromJson(value))
            .toList();
  }

  static Map<String, DocumentLinksFile> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, DocumentLinksFile>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = DocumentLinksFile.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (href != null) 'href': href,
      if (iriTemplate != null) 'iriTemplate': iriTemplate,
    };
  }

  @override
  String toString() {
    return 'DocumentLinksFile[href=$href, iriTemplate=$iriTemplate, ]';
  }
}

==> keyclic_sdk_api-2.3.8.tar.gz: lib/model/document_links_file.dart <==
part of keyclic_sdk_api.api;

class DocumentLinksFile {
  DocumentLinksFile({
    this.href,
    this.iriTemplate,
  });

  factory DocumentLinksFile.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return DocumentLinksFile(
      href: json['href'],
      iriTemplate: DocumentLinksFileIriTemplate.fromJson(json['iriTemplate']),
    );
  }

  /* The URI of the file associated to the given document. */
  String href;

  DocumentLinksFileIriTemplate iriTemplate;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is DocumentLinksFile &&
        runtimeType == other.runtimeType &&
        href == other.href &&
        iriTemplate == other.iriTemplate;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= href?.hashCode ?? 0;
    hashCode ^= iriTemplate?.hashCode ?? 0;

    return hashCode;
  }

  static List<DocumentLinksFile> listFromJson(List<dynamic> json) {
    return json
            ?.map((dynamic value) => DocumentLinksFile.fromJson(value))
            ?.toList() ??
        <DocumentLinksFile>[];
  }

  static Map<String, DocumentLinksFile> mapFromJson(Map<String, dynamic> json) {
    return json?.map((String key, dynamic value) {
          return MapEntry(key, DocumentLinksFile.fromJson(value));
        }) ??
        <String, DocumentLinksFile>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (href != null) 'href': href,
      if (iriTemplate != null) 'iriTemplate': iriTemplate.toJson(),
    };
  }

  @override
  String toString() {
    return 'DocumentLinksFile[href=$href, iriTemplate=$iriTemplate, ]';
  }
}
